@@ -3,7 +3,6 @@ var searchData=
   ['saxdocumentbuilder_2eidl',['SAXDocumentBuilder.idl',['../SAXDocumentBuilder_8idl.html',1,'']]],
   ['saxdocumentbuilderstate_2eidl',['SAXDocumentBuilderState.idl',['../SAXDocumentBuilderState_8idl.html',1,'']]],
   ['saxdocumenthandler_2eidl',['SaxDocumentHandler.idl',['../SaxDocumentHandler_8idl.html',1,'']]],
-  ['saxeventkeeper_2eidl',['SAXEventKeeper.idl',['../SAXEventKeeper_8idl.html',1,'']]],
   ['saxexception_2eidl',['SAXException.idl',['../SAXException_8idl.html',1,'']]],
   ['saxinvalidcharacterexception_2eidl',['SAXInvalidCharacterException.idl',['../SAXInvalidCharacterException_8idl.html',1,'']]],
   ['saxparseexception_2eidl',['SAXParseException.idl',['../SAXParseException_8idl.html',1,'']]],
@@ -73,11 +72,9 @@ var searchData=
   ['sessionmanager_2eidl',['SessionManager.idl',['../SessionManager_8idl.html',1,'']]],
   ['setaccess_2eidl',['SetAccess.idl',['../SetAccess_8idl.html',1,'']]],
   ['setelement_2eidl',['SetElement.idl',['../SetElement_8idl.html',1,'']]],
-  ['setexpression_2eidl',['SetExpression.idl',['../fieldmaster_2SetExpression_8idl.html',1,'']]],
-  ['setexpression_2eidl',['SetExpression.idl',['../textfield_2SetExpression_8idl.html',1,'']]],
+  ['setexpression_2eidl',['SetExpression.idl',['../fieldmaster_2SetExpression_8idl.html',1,'(Global Namespace)'],['../textfield_2SetExpression_8idl.html',1,'(Global Namespace)']]],
   ['setpropertytolerantfailed_2eidl',['SetPropertyTolerantFailed.idl',['../SetPropertyTolerantFailed_8idl.html',1,'']]],
-  ['settings_2eidl',['Settings.idl',['../frame_2Settings_8idl.html',1,'']]],
-  ['settings_2eidl',['Settings.idl',['../document_2Settings_8idl.html',1,'']]],
+  ['settings_2eidl',['Settings.idl',['../document_2Settings_8idl.html',1,'(Global Namespace)'],['../frame_2Settings_8idl.html',1,'(Global Namespace)']]],
   ['setupdate_2eidl',['SetUpdate.idl',['../SetUpdate_8idl.html',1,'']]],
   ['setvariabletype_2eidl',['SetVariableType.idl',['../SetVariableType_8idl.html',1,'']]],
   ['shademode_2eidl',['ShadeMode.idl',['../ShadeMode_8idl.html',1,'']]],
@@ -85,11 +82,7 @@ var searchData=
   ['shadowformat_2eidl',['ShadowFormat.idl',['../ShadowFormat_8idl.html',1,'']]],
   ['shadowlocation_2eidl',['ShadowLocation.idl',['../ShadowLocation_8idl.html',1,'']]],
   ['shadowproperties_2eidl',['ShadowProperties.idl',['../ShadowProperties_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../drawing_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../text_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../presentation_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../report_2Shape_8idl.html',1,'']]],
-  ['shape_2eidl',['Shape.idl',['../sheet_2Shape_8idl.html',1,'']]],
+  ['shape_2eidl',['Shape.idl',['../drawing_2Shape_8idl.html',1,'(Global Namespace)'],['../presentation_2Shape_8idl.html',1,'(Global Namespace)'],['../report_2Shape_8idl.html',1,'(Global Namespace)'],['../sheet_2Shape_8idl.html',1,'(Global Namespace)'],['../text_2Shape_8idl.html',1,'(Global Namespace)']]],
   ['shapeanimationsubtype_2eidl',['ShapeAnimationSubType.idl',['../ShapeAnimationSubType_8idl.html',1,'']]],
   ['shapecollection_2eidl',['ShapeCollection.idl',['../ShapeCollection_8idl.html',1,'']]],
   ['shapes_2eidl',['Shapes.idl',['../Shapes_8idl.html',1,'']]],
@@ -107,13 +100,10 @@ var searchData=
   ['sheetrangesquery_2eidl',['SheetRangesQuery.idl',['../SheetRangesQuery_8idl.html',1,'']]],
   ['sheetsortdescriptor_2eidl',['SheetSortDescriptor.idl',['../SheetSortDescriptor_8idl.html',1,'']]],
   ['sheetsortdescriptor2_2eidl',['SheetSortDescriptor2.idl',['../SheetSortDescriptor2_8idl.html',1,'']]],
-  ['signaturecreator_2eidl',['SignatureCreator.idl',['../SignatureCreator_8idl.html',1,'']]],
   ['signatureexception_2eidl',['SignatureException.idl',['../SignatureException_8idl.html',1,'']]],
-  ['signatureverifier_2eidl',['SignatureVerifier.idl',['../SignatureVerifier_8idl.html',1,'']]],
   ['simplecommandmail_2eidl',['SimpleCommandMail.idl',['../SimpleCommandMail_8idl.html',1,'']]],
   ['simplefileaccess_2eidl',['SimpleFileAccess.idl',['../SimpleFileAccess_8idl.html',1,'']]],
   ['simplefontmetric_2eidl',['SimpleFontMetric.idl',['../SimpleFontMetric_8idl.html',1,'']]],
-  ['simplelogring_2eidl',['SimpleLogRing.idl',['../SimpleLogRing_8idl.html',1,'']]],
   ['simplemailclientflags_2eidl',['SimpleMailClientFlags.idl',['../SimpleMailClientFlags_8idl.html',1,'']]],
   ['simpleregistry_2eidl',['SimpleRegistry.idl',['../SimpleRegistry_8idl.html',1,'']]],
   ['simplesetaccess_2eidl',['SimpleSetAccess.idl',['../SimpleSetAccess_8idl.html',1,'']]],
@@ -180,9 +170,7 @@ var searchData=
   ['standarddiagramcreationparameters_2eidl',['StandardDiagramCreationParameters.idl',['../StandardDiagramCreationParameters_8idl.html',1,'']]],
   ['startmodule_2eidl',['StartModule.idl',['../StartModule_8idl.html',1,'']]],
   ['statechangeinprogressexception_2eidl',['StateChangeInProgressException.idl',['../StateChangeInProgressException_8idl.html',1,'']]],
-  ['statement_2eidl',['Statement.idl',['../sdbcx_2Statement_8idl.html',1,'']]],
-  ['statement_2eidl',['Statement.idl',['../sdbc_2Statement_8idl.html',1,'']]],
-  ['statement_2eidl',['Statement.idl',['../rdf_2Statement_8idl.html',1,'']]],
+  ['statement_2eidl',['Statement.idl',['../rdf_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbc_2Statement_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Statement_8idl.html',1,'(Global Namespace)']]],
   ['statusbarcontroller_2eidl',['StatusbarController.idl',['../StatusbarController_8idl.html',1,'']]],
   ['statusbarcontrollerfactory_2eidl',['StatusbarControllerFactory.idl',['../StatusbarControllerFactory_8idl.html',1,'']]],
   ['statusbarfunction_2eidl',['StatusBarFunction.idl',['../StatusBarFunction_8idl.html',1,'']]],
@@ -203,15 +191,13 @@ var searchData=
   ['stringresourcewithlocation_2eidl',['StringResourceWithLocation.idl',['../StringResourceWithLocation_8idl.html',1,'']]],
   ['stringresourcewithstorage_2eidl',['StringResourceWithStorage.idl',['../StringResourceWithStorage_8idl.html',1,'']]],
   ['strokeattributes_2eidl',['StrokeAttributes.idl',['../StrokeAttributes_8idl.html',1,'']]],
-  ['style_2eidl',['Style.idl',['../awt_2Style_8idl.html',1,'']]],
-  ['style_2eidl',['Style.idl',['../style_2Style_8idl.html',1,'']]],
+  ['style_2eidl',['Style.idl',['../awt_2Style_8idl.html',1,'(Global Namespace)'],['../style_2Style_8idl.html',1,'(Global Namespace)']]],
   ['stylefamilies_2eidl',['StyleFamilies.idl',['../StyleFamilies_8idl.html',1,'']]],
   ['stylefamily_2eidl',['StyleFamily.idl',['../StyleFamily_8idl.html',1,'']]],
   ['subincrement_2eidl',['SubIncrement.idl',['../SubIncrement_8idl.html',1,'']]],
   ['subject_2eidl',['Subject.idl',['../Subject_8idl.html',1,'']]],
   ['submissionpropertyhandler_2eidl',['SubmissionPropertyHandler.idl',['../SubmissionPropertyHandler_8idl.html',1,'']]],
-  ['submitbutton_2eidl',['SubmitButton.idl',['../control_2SubmitButton_8idl.html',1,'']]],
-  ['submitbutton_2eidl',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'']]],
+  ['submitbutton_2eidl',['SubmitButton.idl',['../component_2SubmitButton_8idl.html',1,'(Global Namespace)'],['../control_2SubmitButton_8idl.html',1,'(Global Namespace)']]],
   ['subtitleshape_2eidl',['SubtitleShape.idl',['../SubtitleShape_8idl.html',1,'']]],
   ['subtotalcolumn_2eidl',['SubTotalColumn.idl',['../SubTotalColumn_8idl.html',1,'']]],
   ['subtotaldescriptor_2eidl',['SubTotalDescriptor.idl',['../SubTotalDescriptor_8idl.html',1,'']]],
